@@ -1,7 +1,7 @@
 package App::wdq;
 use v5.14;
 
-our $VERSION = '0.1.0';
+our $VERSION = '0.1.1';
 
 1;
 __END__
@@ -27,7 +27,7 @@ Either install from CPAN with all dependencies:
   cpanm App::wdq
 
 or install dependencies as prebuild packages (for instance Debian) and copy
-the `wdq` script at some place in your C<$PATH>:
+the L<wdq> script to some place in your C<$PATH>:
 
   apt-get install libhttp-tiny-perl librdf-query-perl
   wget https://github.com/nichtich/wdq/raw/master/bin/wdq
